@@ -1,7 +1,10 @@
 from django.conf.urls import url, include
-from django_spaghetti.views import plate, Plate
+from django_spaghetti.views import Plate
 
 urlpatterns = [
+    url(r'^$', Plate.as_view(
+        plate_template_name="tests/home_plate.html"
+    ), name='test_plate_override$'),
     url(r'^test/plate_settings$', Plate.as_view(
         settings={
             'apps': ['auth'],
@@ -20,6 +23,6 @@ urlpatterns = [
             },
         },
         meatball_template_name="tests/meatball.html"
-    ), name='test_plate_override$'),
+    ), name='test_plate_override'),
     url(r'plate', include('django_spaghetti.urls', namespace="spaghetti")),
 ]
